@@ -1,5 +1,4 @@
 from graphite_exporter import main
 
-
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
